"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const auth0_1 = require("auth0");
class Auth0Service {
    constructor({ domain, clientId, clientSecret }) {
        this.settings = { domain, clientId, clientSecret };
        this.auth = new auth0_1.AuthenticationClient({
            domain,
            clientId,
            clientSecret,
            scope: "openid app_metadata user_metadata",
        });
        this.management = new auth0_1.ManagementClient({
            domain,
            clientId,
            clientSecret,
            scope: "read:users write:users"
        });
    }
    async signInLoginPassword(username, password) {
        const result = await this.auth.database.signIn({ username, password });
        return this.getProfile(result.access_token);
    }
    async signInOAuth(access_token, connection) {
        const result = await this.auth.oauth.socialSignIn({ access_token, connection });
        return this.getProfile(result.access_token);
    }
    async getProfile(accessToken) {
        const result = await this.auth.getProfile(accessToken);
        return result;
    }
    async getPublicProfile(id) {
        try {
            const result = await this.management.getUser({ id });
            return result;
        }
        catch (e) {
            console.log(e);
            return {};
        }
    }
}
exports.Auth0Service = Auth0Service;
//# sourceMappingURL=Auth0Service.js.map